RDFFormats.Writers.Writer

Package RDFFormats :: Module Writers :: Class Writer |
[show private | hide private]
[frames | no frames]

## Class Writer

Known Subclasses:
  `Writer`

    A writer class which, acting as a visitor on nodes in a store, employs a
    format writer in order to produce actual output.

Method Summary
| `__init__(self, format_writer)`
| `is_attribute_permitted(self, attribute_name, element_name)`
| `is_element_permitted(self, subelement_name, element_name)`
| ``write`(self, store, node)` Write, using the 'store', the resource rooted at the given 'node'.
| ``write_element`(self, store, node, node_type)` Write the element found in the 'store' represented by the given 'node' and having the given 'node_type'.

Method Details

### write(self, store, node)
    Write, using the 'store', the resource rooted at the given 'node'.

### write_element(self, store, node, node_type)
    Write the element found in the 'store' represented by the given 'node'
    and having the given 'node_type'.

Generated by Epydoc 2.1 on Sat Jul 7 19:42:53 2007 | http://epydoc.sf.net